=======
Support
=======

Feel free to try MSS on a system we had not tested, and let us know by creating an `issue <https://github.com/BoboTiG/python-mss/issues>`_.

    - OS: GNU/Linux, macOS, and Windows
    - Python: 3.9 and newer


Future
======

- Support `ReactOS <https://www.reactos.org>`_ and other systems on OS stability or available hardware.
- Any idea?


Others
======

Tested successfully on Pypy 5.1.0 on Windows, but speed is terrible.


Abandoned
=========

- Python 2.6 (2016-10-08)
- Python 2.7 (2019-01-31)
- Python 3.0 (2016-10-08)
- Python 3.1 (2016-10-08)
- Python 3.2 (2016-10-08)
- Python 3.3 (2017-12-05)
- Python 3.4 (2018-03-19)
- Python 3.5 (2022-10-27)
- Python 3.6 (2022-10-27)
- Python 3.7 (2023-04-09)
- Python 3.8 (2024-11-14)
